@@ -32,6 +32,7 @@ function FilterCheckbox({ filterKey }: FilterCheckboxProps) {
 
   return (
     <FormControlLabel
+      className="tw-m-0 tw-flex tw-items-center"
       control={
         <Checkbox
           checkedIcon={<CheckboxIcon checked />}
@@ -57,6 +58,7 @@ const ENABLED_FILTERS: FilterKey[] = ['community', 'workingGroup', 'other'];
  */
 export function CalendarFilter() {
   const [open, setOpen] = useState(false);
+  const [popupWidth, setPopupWidth] = useState<string | number>('100%');
   const anchorElRef = useRef<HTMLDivElement>(null);
   const paperElRef = useRef<HTMLDivElement>(null);
 
@@ -68,11 +70,11 @@ export function CalendarFilter() {
     <div
       className={clsx(
         'tw-flex tw-flex-col tw-col-start-2',
-        'tw-justify-center tw-w-full',
-        'screen-900:tw-flex-row screen-900:tw-space-x-2',
+        'tw-items-start tw-w-full',
+        'screen-900:tw-items-center screen-900:tw-flex-row screen-900:tw-space-x-2',
       )}
     >
-      <span className="tw-font-semibold">show:</span>
+      <span className="tw-font-semibold tw-ml-2 screen-900:tw-m-0">show:</span>
 
       {ENABLED_FILTERS.map((filterKey) => (
         <FilterCheckbox filterKey={filterKey} key={filterKey} />
@@ -97,9 +99,16 @@ export function CalendarFilter() {
         <div className="screen-900:tw-hidden">
           <Button
             classes={{
-              label: 'tw-underline',
+              label: 'tw-underline tw-font-normal',
+            }}
+            onClick={() => {
+              setOpen((prev) => !prev);
+              const width = anchorElRef.current?.parentElement?.offsetWidth;
+
+              if (width) {
+                setPopupWidth(width);
+              }
             }}
-            onClick={() => setOpen((prev) => !prev)}
             variant="text"
           >
             filter events
@@ -120,11 +129,14 @@ export function CalendarFilter() {
             <Paper
               className={clsx(
                 'tw-grid tw-grid-cols-[2rem,1fr,min-content]',
-                'tw-items-center tw-px-9',
+                'tw-items-center tw-px-6 tw-py-5',
                 'napari-calendar__popup',
               )}
               ref={paperElRef}
               elevation={0}
+              style={{
+                width: popupWidth,
+              }}
             >
               {filterBody}
             </Paper>
