@@ -11,8 +11,8 @@ export function Close({ className, alt }: IconProps) {
       xmlns="http://www.w3.org/2000/svg"
     >
       {alt && <title>{alt}</title>}
-      <path d="M1 1L17 17" stroke="white" strokeWidth="2.35294" />
-      <path d="M17 1L1 17" stroke="white" strokeWidth="2.35294" />
+      <path d="M1 1L17 17" stroke="#000" strokeWidth="2.35294" />
+      <path d="M17 1L1 17" stroke="#000" strokeWidth="2.35294" />
     </svg>
   );
 }
